@@ -99,6 +99,16 @@ def angle_2d(p_1, p_2):
     return dtheta
 
 
+def quadratic_bezier(curv_pos, points):
+    curve_x = (1 - curv_pos) * (
+        (1 - curv_pos) * points[0][0] + curv_pos * points[1][0]
+    ) + curv_pos * ((1 - curv_pos) * points[1][0] + curv_pos * points[2][0])
+    curve_y = (1 - curv_pos) * (
+        (1 - curv_pos) * points[0][1] + curv_pos * points[1][1]
+    ) + curv_pos * ((1 - curv_pos) * points[1][1] + curv_pos * points[2][1])
+    return curve_x, curve_y
+
+
 # ########## Object & Segments Functions ###########
 
 
@@ -926,3 +936,15 @@ def rotate_objects(objects: dict, min_max: list[float]) -> None:
             segment["bulge"] = -segment["bulge"]
         reverse_object(obj)
     mirror_objects(objects, min_max, horizontal=True)
+
+
+def scale_objects(objects: dict, scale: float) -> None:
+    """rotates an object"""
+    for obj in objects.values():
+        for segment in obj["segments"]:
+            for ptype in ("start", "end", "center"):
+                if ptype in segment:
+                    segment[ptype] = (
+                        segment[ptype][0] * scale,
+                        segment[ptype][1] * scale,
+                    )
