@@ -29,6 +29,7 @@ from PyQt5.QtWidgets import (  # pylint: disable=E0611
     QFileDialog,
     QGridLayout,
     QHBoxLayout,
+    QInputDialog,
     QLabel,
     QLineEdit,
     QMainWindow,
@@ -59,6 +60,7 @@ from .calc import (
     objects2minmax,
     objects2polyline_offsets,
     rotate_objects,
+    scale_objects,
     segments2objects,
 )
 from .gldraw import (
@@ -72,6 +74,7 @@ from .input_plugins.dxfread import DxfReader
 from .input_plugins.hpglread import HpglReader
 from .input_plugins.stlread import StlReader
 from .input_plugins.svgread import SvgReader
+from .input_plugins.ttfread import TtfReader
 from .machine_cmd import polylines2machine_cmd
 from .output_plugins.gcode_linuxcnc import PostProcessorGcodeLinuxCNC
 from .output_plugins.hpgl import PostProcessorHpgl
@@ -493,9 +496,10 @@ class ViaConstructor:
             "table": None,
         },
     }
+    info = ""
     save_tabs = "no"
     save_starts = "no"
-    draw_reader: Union[DxfReader, SvgReader, HpglReader, StlReader]
+    draw_reader: Union[DxfReader, SvgReader, HpglReader, StlReader, TtfReader]
 
     def run_calculation(self) -> None:
         """run all calculations."""
@@ -564,6 +568,19 @@ class ViaConstructor:
         self.project["minMax"] = objects2minmax(self.project["objects"])
         self.update_drawing()
 
+    def _toolbar_scale(self) -> None:
+        scale, dialog_ok = QInputDialog.getText(
+            self.project["window"], _("Workpiece-Scale"), _("Scale-Factor:"), text="1.0"
+        )
+        if (
+            dialog_ok
+            and str(scale).replace(".", "").isnumeric()
+            and float(scale) != 1.0
+        ):
+            scale_objects(self.project["objects"], float(scale))
+            self.project["minMax"] = objects2minmax(self.project["objects"])
+            self.update_drawing()
+
     def _toolbar_view_2d(self) -> None:
         """center view."""
         self.project["glwidget"].view_2d()
@@ -597,7 +614,7 @@ class ViaConstructor:
 
     def _toolbar_save_machine_cmd(self) -> None:
         """save machine_cmd."""
-        self.status_bar.showMessage("save machine_cmd..")
+        self.status_bar.showMessage(f"{self.info} - save machine_cmd..")
         file_dialog = QFileDialog(self.main)
         file_dialog.setNameFilters(
             [f"self.project['suffix'] (*.{self.project['suffix']})"]
@@ -612,9 +629,11 @@ class ViaConstructor:
             f"{self.project['suffix']} (*.{self.project['suffix']})",
         )
         if name[0] and self.machine_cmd_save(name[0]):
-            self.status_bar.showMessage(f"save maschine-code..done ({name[0]})")
+            self.status_bar.showMessage(
+                f"{self.info} - save maschine-code..done ({name[0]})"
+            )
         else:
-            self.status_bar.showMessage("save maschine-code..cancel")
+            self.status_bar.showMessage(f"{self.info} - save maschine-code..cancel")
 
     def setup_load(self, filename: str) -> bool:
         if os.path.isfile(filename):
@@ -634,15 +653,15 @@ class ViaConstructor:
 
     def _toolbar_save_setup(self) -> None:
         """save setup."""
-        self.status_bar.showMessage("save setup..")
+        self.status_bar.showMessage(f"{self.info} - save setup..")
         if self.setup_save(self.args.setup):
-            self.status_bar.showMessage("save setup..done")
+            self.status_bar.showMessage(f"{self.info} - save setup..done")
         else:
-            self.status_bar.showMessage("save setup..error")
+            self.status_bar.showMessage(f"{self.info} - save setup..error")
 
     def _toolbar_load_setup_from(self) -> None:
         """load setup from."""
-        self.status_bar.showMessage("load setup from..")
+        self.status_bar.showMessage(f"{self.info} - load setup from..")
         file_dialog = QFileDialog(self.main)
         file_dialog.setNameFilters(["setup (*.json)"])
         name = file_dialog.getOpenFileName(
@@ -653,26 +672,30 @@ class ViaConstructor:
             self.update_table()
             self.global_changed(0)
             self.update_drawing()
-            self.status_bar.showMessage(f"load setup from..done ({name[0]})")
+            self.status_bar.showMessage(
+                f"{self.info} - load setup from..done ({name[0]})"
+            )
         else:
-            self.status_bar.showMessage("load setup from..cancel")
+            self.status_bar.showMessage(f"{self.info} - load setup from..cancel")
 
     def _toolbar_save_setup_as(self) -> None:
         """save setup as."""
-        self.status_bar.showMessage("save setup as..")
+        self.status_bar.showMessage(f"{self.info} - save setup as..")
         file_dialog = QFileDialog(self.main)
         file_dialog.setNameFilters(["setup (*.json)"])
         name = file_dialog.getSaveFileName(
             self.main, "Save Setup", self.args.setup, "setup (*.json)"
         )
         if name[0] and self.setup_save(name[0]):
-            self.status_bar.showMessage(f"save setup as..done ({name[0]})")
+            self.status_bar.showMessage(
+                f"{self.info} - save setup as..done ({name[0]})"
+            )
         else:
-            self.status_bar.showMessage("save setup as..cancel")
+            self.status_bar.showMessage(f"{self.info} - ave setup as..cancel")
 
     def update_drawing(self, draw_only=False) -> None:
         """update drawings."""
-        self.status_bar.showMessage("calculate..")
+        self.status_bar.showMessage(f"{self.info} - calculate..")
         if not draw_only:
             self.run_calculation()
         self.project["gllist"] = GL.glGenLists(1)
@@ -683,7 +706,9 @@ class ViaConstructor:
                 self.draw_reader.draw_3d()
         if not self.project["glwidget"].repair_selector:
             if not draw_maschinecode_path(self.project):
-                self.status_bar.showMessage("error while drawing maschine commands")
+                self.status_bar.showMessage(
+                    f"{self.info} - error while drawing maschine commands"
+                )
 
         if self.project["setup"]["view"]["object_ids"]:
             draw_object_ids(self.project)
@@ -692,7 +717,11 @@ class ViaConstructor:
         if self.project["setup"]["view"]["polygon_show"]:
             draw_object_faces(self.project)
         GL.glEndList()
-        self.status_bar.showMessage("calculate..done")
+        self.info = f"{self.project['minMax'][2] - self.project['minMax'][0]}x{self.project['minMax'][3] - self.project['minMax'][1]}mm"
+        self.main.setWindowTitle(
+            f"viaConstructor: {self.project['filename_draw']} - {self.info}"
+        )
+        self.status_bar.showMessage(f"{self.info} - calculate..done")
 
     def materials_select(self, material_idx) -> None:
         """calculates the milling feedrate and tool-speed for the selected material
@@ -1002,7 +1031,7 @@ class ViaConstructor:
         ] = f"{'.'.join(self.project['filename_draw'].split('.')[:-1])}.{self.project['suffix']}"
         if os.path.isfile(self.project["filename_machine_cmd"]):
             self.status_bar.showMessage(
-                f"loading setup from maschinecode: {self.project['filename_machine_cmd']}"
+                f"{self.info} - loading setup from maschinecode: {self.project['filename_machine_cmd']}"
             )
             with open(self.project["filename_machine_cmd"], "r") as fd_machine_cmd:
                 gdata = fd_machine_cmd.read()
@@ -1014,10 +1043,12 @@ class ViaConstructor:
                             self.project["setup"][sname].update(ndata.get(sname, {}))
                         self.update_drawing()
                         self.status_bar.showMessage(
-                            "loading setup from maschinecode..done"
+                            f"{self.info} - loading setup from maschinecode..done"
                         )
                         return
-        self.status_bar.showMessage("loading setup from maschinecode..failed")
+        self.status_bar.showMessage(
+            f"{self.info} - loading setup from maschinecode..failed"
+        )
 
     def _toolbar_exit(self) -> None:
         """exit button."""
@@ -1114,6 +1145,14 @@ class ViaConstructor:
                 True,
                 "workpiece",
             ),
+            _("Scale"): (
+                "scale.png",
+                "",
+                _("Scale workpiece"),
+                self._toolbar_scale,
+                True,
+                "workpiece",
+            ),
             _("Tab-Selector"): (
                 "tab-selector.png",
                 "",
@@ -1318,7 +1357,7 @@ class ViaConstructor:
 
     def __init__(self) -> None:
         """viaconstructor main init."""
-        setproctitle.setproctitle("viaconstructor")
+        setproctitle.setproctitle("viaconstructor")  # pylint: disable=I1101
 
         # arguments
         parser = argparse.ArgumentParser()
@@ -1333,9 +1372,25 @@ class ViaConstructor:
         parser.add_argument(
             "-o", "--output", help="save to machine_cmd", type=str, default=None
         )
+        # STL-Reader
         parser.add_argument(
             "-z", "--zslice", help="slice at postion z (stl)", type=str, default=None
         )
+        # TTF-Reader
+        parser.add_argument(
+            "-t",
+            "--text",
+            help="text for the Truetype reader",
+            type=str,
+            default="ViaConstructor",
+        )
+        parser.add_argument(
+            "-th",
+            "--text-height",
+            help="text height for the Truetype reader",
+            type=float,
+            default=100,
+        )
         self.args = parser.parse_args()
 
         # load setup
@@ -1366,6 +1421,8 @@ class ViaConstructor:
             self.draw_reader = HpglReader(self.args.filename, self.args)
         elif self.args.filename.lower().endswith(".stl"):
             self.draw_reader = StlReader(self.args.filename, self.args)
+        elif self.args.filename.lower().endswith(".ttf"):
+            self.draw_reader = TtfReader(self.args.filename, self.args)
         else:
             print(f"ERROR: Unknown file suffix: {self.args.filename}")
             sys.exit(1)
@@ -1381,7 +1438,7 @@ class ViaConstructor:
 
         # gui #
         qapp = QApplication(sys.argv)
-        window = QWidget()
+        self.project["window"] = QWidget()
         self.project["app"] = self
 
         my_format = QGLFormat.defaultFormat()
@@ -1389,7 +1446,7 @@ class ViaConstructor:
         QGLFormat.setDefaultFormat(my_format)
         if not QGLFormat.hasOpenGL():
             QMessageBox.information(
-                window,
+                self.project["window"],
                 "OpenGL using samplebuffers",
                 "This system does not support OpenGL.",
             )
@@ -1399,7 +1456,7 @@ class ViaConstructor:
 
         self.main = QMainWindow()
         self.main.setWindowTitle(f"viaConstructor: {self.project['filename_draw']}")
-        self.main.setCentralWidget(window)
+        self.main.setCentralWidget(self.project["window"])
 
         self.this_dir, self.this_filename = os.path.split(__file__)
 
@@ -1407,7 +1464,7 @@ class ViaConstructor:
 
         self.status_bar = QStatusBar()
         self.main.setStatusBar(self.status_bar)
-        self.status_bar.showMessage("startup")
+        self.status_bar.showMessage(f"{self.info} - startup")
 
         self.project["textwidget"] = QPlainTextEdit()
         self.project["objwidget"] = QTreeView()
@@ -1447,7 +1504,7 @@ class ViaConstructor:
         right_widget = QWidget()
         right_widget.setLayout(right_gridlayout)
 
-        hlay = QHBoxLayout(window)
+        hlay = QHBoxLayout(self.project["window"])
         hlay.addWidget(left_widget, stretch=1)
         hlay.addWidget(right_widget, stretch=3)
 
